summaryrefslogtreecommitdiffstats
path: root/kweather
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 10:00:14 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 10:00:14 -0600
commit4d75f93557ba631d97a56e288a34ca27f4507653 (patch)
tree9c6aa673bd4900debf335044852a99b4d9f67133 /kweather
parent6cdf35ab11c322f33feca5baf090ef56068b6049 (diff)
downloadtdetoys-4d75f93557ba631d97a56e288a34ca27f4507653.tar.gz
tdetoys-4d75f93557ba631d97a56e288a34ca27f4507653.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 6cdf35ab11c322f33feca5baf090ef56068b6049.
Diffstat (limited to 'kweather')
-rw-r--r--kweather/dockwidget.cpp80
-rw-r--r--kweather/kcmweather.cpp8
-rw-r--r--kweather/kcmweatherservice.cpp6
-rw-r--r--kweather/kweather.cpp6
-rw-r--r--kweather/metar_parser.cpp28
-rw-r--r--kweather/metar_parser.h2
-rw-r--r--kweather/prefdialogdata.ui16
-rw-r--r--kweather/reportview.cpp28
-rw-r--r--kweather/serviceconfigdata.ui6
-rw-r--r--kweather/serviceconfigwidget.cpp2
-rw-r--r--kweather/sidebarwidgetbase.ui2
-rw-r--r--kweather/sun.h2
-rw-r--r--kweather/weatherbar.cpp2
-rw-r--r--kweather/weatherbar.h2
-rw-r--r--kweather/weatherbutton.cpp6
-rw-r--r--kweather/weatherlib.cpp12
16 files changed, 104 insertions, 104 deletions
diff --git a/kweather/kcmweather.cpp b/kweather/kcmweather.cpp
index 1037fa1..d49d3a0 100644
--- a/kweather/kcmweather.cpp
+++ b/kweather/kcmweather.cpp
@@ -24,7 +24,7 @@
#include <tqbuttongroup.h>
#include <tqcheckbox.h>
#include <tqlabel.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <kaboutdata.h>
#include <kapplication.h>
@@ -54,12 +54,12 @@ KCMWeather::KCMWeather( TQWidget *parent, const char *name )
{
mWeatherService = new WeatherService_stub( "KWeatherService",
"WeatherService" );
- TQVBoxLayout *layout = new TQVBoxLayout( this );
+ TQVBoxLayout *tqlayout = new TQVBoxLayout( this );
mWidget = new prefsDialogData( this );
mWidget->m_reportLocation->setFocus();
- layout->addWidget( mWidget );
- layout->addStretch();
+ tqlayout->addWidget( mWidget );
+ tqlayout->addStretch();
fillStationList();
load();
diff --git a/kweather/kcmweatherservice.cpp b/kweather/kcmweatherservice.cpp
index 203bddf..db8325d 100644
--- a/kweather/kcmweatherservice.cpp
+++ b/kweather/kcmweatherservice.cpp
@@ -21,7 +21,7 @@
without including the source code for TQt in the source distribution.
*/
-#include <layout.h>
+#include <tqlayout.h>
#include <kaboutdata.h>
#include <kdebug.h>
@@ -41,13 +41,13 @@ extern "C"
KCMWeatherService::KCMWeatherService( TQWidget *parent, const char *name )
: KCModule( parent, name )
{
- TQVBoxLayout *layout = new TQVBoxLayout( this );
+ TQVBoxLayout *tqlayout = new TQVBoxLayout( this );
mWidget = new ServiceConfigWidget( this );
// not needed, as a change immediately changes the service
//connect(mWidget, TQT_SIGNAL(changed(bool)), this, TQT_SIGNAL(changed(bool)));
- layout->addWidget( mWidget );
+ tqlayout->addWidget( mWidget );
KAboutData *about = new KAboutData( "kcmweatherservice",
I18N_NOOP( "KWeather Configure Dialog" ),
0, 0, KAboutData::License_GPL,
diff --git a/kweather/kweather.cpp b/kweather/kweather.cpp
index 9685543..9b8c481 100644
--- a/kweather/kweather.cpp
+++ b/kweather/kweather.cpp
@@ -31,7 +31,7 @@
#include <tqfile.h>
#include <tqtimer.h>
-#include <palette.h>
+#include <tqpalette.h>
#include "kweather.h"
#include "reportview.h"
@@ -86,7 +86,7 @@ kweather::~kweather()
void kweather::initContextMenu()
{
mContextMenu = new KPopupMenu(this);
- mContextMenu->insertTitle(i18n("KWeather - %1").arg( reportLocation ), -1, 0);
+ mContextMenu->insertTitle(i18n("KWeather - %1").tqarg( reportLocation ), -1, 0);
mContextMenu->insertItem(SmallIcon("viewmag"), i18n("Show &Report"),
this, TQT_SLOT(doReport()), 0, -1, 1);
mContextMenu->insertItem(SmallIcon("reload"), i18n("&Update Now"),
@@ -171,7 +171,7 @@ void kweather::preferences()
/** The help handler */
void kweather::help()
{
- kapp->invokeHelp(TQString(), TQString::fromLatin1("kweather"));
+ kapp->invokeHelp(TQString(), TQString::tqfromLatin1("kweather"));
}
/** Display the current weather report. */
diff --git a/kweather/metar_parser.cpp b/kweather/metar_parser.cpp
index b6715f0..2d3eab9 100644
--- a/kweather/metar_parser.cpp
+++ b/kweather/metar_parser.cpp
@@ -147,7 +147,7 @@ bool MetarParser::parseCover(const TQString &s)
{
if (CoverRegExp.search(s) > -1)
{
- kdDebug(12006) << "Cover: " << TQString(CoverRegExp.capturedTexts().join("-"))
+ kdDebug(12006) << "Cover: " << TQString(CoverRegExp.tqcapturedTexts().join("-"))
<< endl;
TQString sCode = CoverRegExp.cap(1);
@@ -170,22 +170,22 @@ bool MetarParser::parseCover(const TQString &s)
if (sCode == "FEW")
{
- skycondition = i18n( "Few clouds at %1" ).arg(sClouds);
+ skycondition = i18n( "Few clouds at %1" ).tqarg(sClouds);
weatherInfo.clouds += 2;
}
else if (sCode == "SCT")
{
- skycondition = i18n( "Scattered clouds at %1" ).arg(sClouds);
+ skycondition = i18n( "Scattered clouds at %1" ).tqarg(sClouds);
weatherInfo.clouds += 4;
}
else if (sCode == "BKN")
{
- skycondition = i18n( "Broken clouds at %1" ).arg(sClouds);
+ skycondition = i18n( "Broken clouds at %1" ).tqarg(sClouds);
weatherInfo.clouds += 8;
}
else if (sCode == "OVC")
{
- skycondition = i18n( "Overcast clouds at %1" ).arg(sClouds);
+ skycondition = i18n( "Overcast clouds at %1" ).tqarg(sClouds);
weatherInfo.clouds += 64;
}
else if ((sCode == "CLR") || (sCode == "SKC") || (sCode == "CAVOK"))
@@ -211,7 +211,7 @@ bool MetarParser::parseCurrent(const TQString &s)
TQString sCode = CurrentRegExp.cap(2);
TQString intensity, descriptor, phenomena, currentWeather;
- kdDebug(12006) << "Current: " << TQString(CurrentRegExp.capturedTexts().join("-")) << endl;
+ kdDebug(12006) << "Current: " << TQString(CurrentRegExp.tqcapturedTexts().join("-")) << endl;
// Decode the intensity
if (sIntensity == "+")
@@ -343,7 +343,7 @@ bool MetarParser::parseCurrent(const TQString &s)
else if (sCode.contains("DS"))
phenomena = i18n("Dust Storm");
- if (currentWeather.isEmpty()) currentWeather = i18n("%1 is the intensity, %2 is the descriptor and %3 is the phenomena", "%1 %2 %3").arg(intensity).arg(descriptor).arg(phenomena);
+ if (currentWeather.isEmpty()) currentWeather = i18n("%1 is the intensity, %2 is the descriptor and %3 is the phenomena", "%1 %2 %3").tqarg(intensity).tqarg(descriptor).tqarg(phenomena);
if (!currentWeather.isEmpty())
weatherInfo.qsCurrentList << currentWeather;
@@ -358,7 +358,7 @@ bool MetarParser::parseTemperature(const TQString &s)
{
if (TempRegExp.search(s) > -1)
{
- kdDebug(12006) << "Temp: " << TQString(TempRegExp.capturedTexts().join("-"))
+ kdDebug(12006) << "Temp: " << TQString(TempRegExp.tqcapturedTexts().join("-"))
<< endl;
float fTemp = TempRegExp.cap(2).toFloat();
@@ -379,7 +379,7 @@ bool MetarParser::parseTemperatureTenths(const TQString &s)
{
if (TempTenRegExp.search(s) > -1)
{
- kdDebug(12006) << "Temp Tenths: " << TQString(TempTenRegExp.capturedTexts().join("-"))
+ kdDebug(12006) << "Temp Tenths: " << TQString(TempTenRegExp.tqcapturedTexts().join("-"))
<< endl;
float temperature = TempTenRegExp.cap( 1 ).toFloat() / 10;
@@ -473,7 +473,7 @@ bool MetarParser::parseDate(const TQString &s)
{
if (DateRegExp.search(s) > -1)
{
- kdDebug(12006) << "Date: " << TQString(DateRegExp.capturedTexts().join("-"))
+ kdDebug(12006) << "Date: " << TQString(DateRegExp.tqcapturedTexts().join("-"))
<< endl;
TQString dateString = DateRegExp.cap(1);
TQString day, month, year;
@@ -496,7 +496,7 @@ bool MetarParser::parseTime(const TQString &s)
{
if (TimeRegExp.search(s) > -1)
{
- kdDebug(12006) << "Time: " << TQString(TimeRegExp.capturedTexts().join("-"))
+ kdDebug(12006) << "Time: " << TQString(TimeRegExp.tqcapturedTexts().join("-"))
<< endl;
TQString hour, minute, dateString;
@@ -521,7 +521,7 @@ bool MetarParser::parseVisibility(TQStringList::ConstIterator it)
{
fVisibility = VisRegExp.cap(1).toFloat();
- kdDebug(12006) << "Visibility: " << TQString(VisRegExp.capturedTexts().join("-"))
+ kdDebug(12006) << "Visibility: " << TQString(VisRegExp.tqcapturedTexts().join("-"))
<< endl;
}
@@ -564,7 +564,7 @@ bool MetarParser::parsePressure( const TQString &s)
TQString type = PressRegExp.cap(1);
float fPressure = PressRegExp.cap(2).toFloat();
- kdDebug(12006) << "Pressure: " << TQString(PressRegExp.capturedTexts().join("-"))
+ kdDebug(12006) << "Pressure: " << TQString(PressRegExp.tqcapturedTexts().join("-"))
<< endl;
if (m_units == KLocale::Metric)
@@ -643,7 +643,7 @@ bool MetarParser::parseWindSpeed(const TQString &s)
float gustSpeed = WindRegExp.cap(3).toFloat();
TQString sWindUnit = WindRegExp.cap(4);
- kdDebug(12006) << "Wind: " << WindRegExp.capturedTexts().join("-")
+ kdDebug(12006) << "Wind: " << WindRegExp.tqcapturedTexts().join("-")
<< endl;
if (m_units == KLocale::Metric)
diff --git a/kweather/metar_parser.h b/kweather/metar_parser.h
index daeddad..7d94149 100644
--- a/kweather/metar_parser.h
+++ b/kweather/metar_parser.h
@@ -60,7 +60,7 @@ class MetarParser
public:
MetarParser(StationDatabase *stationDB,
KLocale::MeasureSystem units = KLocale::Imperial,
- TQDate date = TQDate::currentDate(),
+ TQDate date = TQDate::tqcurrentDate(),
TQTime time = TQTime::currentTime(),
unsigned int localUTCOffset = KRFCDate::localUTCOffset());
diff --git a/kweather/prefdialogdata.ui b/kweather/prefdialogdata.ui
index c0878ce..590a2c2 100644
--- a/kweather/prefdialogdata.ui
+++ b/kweather/prefdialogdata.ui
@@ -21,7 +21,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="minimumSize">
+ <property name="tqminimumSize">
<size>
<width>0</width>
<height>0</height>
@@ -85,7 +85,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="minimumSize">
+ <property name="tqminimumSize">
<size>
<width>0</width>
<height>0</height>
@@ -102,7 +102,7 @@
<property name="sizeType">
<enum>MinimumExpanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>40</width>
<height>20</height>
@@ -129,7 +129,7 @@
<property name="title">
<string>Panel Display Options</string>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>AlignVCenter|AlignLeft</set>
</property>
<property name="exclusive">
@@ -228,7 +228,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>294</width>
<height>16</height>
@@ -256,7 +256,7 @@
<property name="enabled">
<bool>false</bool>
</property>
- <property name="minimumSize">
+ <property name="tqminimumSize">
<size>
<width>252</width>
<height>0</height>
@@ -284,7 +284,7 @@
</property>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout1</cstring>
+ <cstring>tqlayout1</cstring>
</property>
<hbox>
<property name="name">
@@ -318,7 +318,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>170</width>
<height>20</height>
diff --git a/kweather/reportview.cpp b/kweather/reportview.cpp
index 39b5536..f25df19 100644
--- a/kweather/reportview.cpp
+++ b/kweather/reportview.cpp
@@ -72,7 +72,7 @@ void reportView::render(){
TQString textColor = KGlobalSettings::textColor().name();
TQString baseColor = KGlobalSettings::baseColor().name();
- TQColorGroup cg = palette().active();
+ TQColorGroup cg = tqpalette().active();
TQString bgColor = cg.background().name();
TQString hlColor = cg.highlight().name();
TQString hlTextColor = cg.highlightedText().name();
@@ -93,7 +93,7 @@ void reportView::render(){
TQStringList cover = m_weatherService->cover(m_locationCode );
TQStringList weather = m_weatherService->weather(m_locationCode );
- setCaption(i18n("Weather Report - %1").arg( locationName ) );
+ setCaption(i18n("Weather Report - %1").tqarg( locationName ) );
TQString weatherText = "<ul>\n";
@@ -114,24 +114,24 @@ void reportView::render(){
TQString contents =
"<html><head><style type=\"text/css\">" +
TQString("body { font-family: \"%1\"; font-size: %2pt; color: %3; background-color: %4; }\n")
- .arg(fntFamily).arg(fntSize).arg(textColor).arg(baseColor) +
+ .tqarg(fntFamily).tqarg(fntSize).tqarg(textColor).tqarg(baseColor) +
TQString("div.headerTitle { background-color: %1; color: %2; padding: 4px; font-size: 120%; border: solid %3 1px; }\n")
- .arg(hlColor).arg(hlTextColor).arg(textColor) +
+ .tqarg(hlColor).tqarg(hlTextColor).tqarg(textColor) +
TQString("div.headerMsg { background-color: %1; color: %2; border-bottom: solid %3 1px; "
"border-left: solid %4 1px; border-right: solid %5 1px; margin-bottom: 1em; padding: 2px; }\n")
- .arg(bgColor).arg(textColor).arg(textColor).arg(textColor).arg(textColor) +
- TQString("</style><title></title></head><body dir=\"%1\">").arg( TQApplication::reverseLayout()?"rtl":"ltr") +
- "<div class=\"headerTitle\"><b>" + i18n( "Weather Report - %1 - %2" ).arg( locationName ).arg( countryName ) +
+ .tqarg(bgColor).tqarg(textColor).tqarg(textColor).tqarg(textColor).tqarg(textColor) +
+ TQString("</style><title></title></head><body dir=\"%1\">").tqarg( TQApplication::reverseLayout()?"rtl":"ltr") +
+ "<div class=\"headerTitle\"><b>" + i18n( "Weather Report - %1 - %2" ).tqarg( locationName ).tqarg( countryName ) +
"</b></div>\n";
if ( ! date.isEmpty() )
- contents += "<div class=\"headerMsg\"><b>" + i18n( "Latest data from %1" ).arg(date) + "</b></div>\n";
+ contents += "<div class=\"headerMsg\"><b>" + i18n( "Latest data from %1" ).tqarg(date) + "</b></div>\n";
contents += TQString(
"<table><tr><td width=\"60\" style=\"text-align: center; border: dotted %1 1px;\">"
"<img width=\"64\" height=\"64\" src=\"%2\" /></td>"
"<td style=\"vertical-align: top\">%3</td></tr>")
- .arg(bgColor).arg(KURL(icon).url()).arg(weatherText) +
+ .tqarg(bgColor).tqarg(KURL(icon).url()).tqarg(weatherText) +
"</table><table>" +
TQString("<tr><th style=\"text-align: right\">" + i18n( "Temperature:" )
+ "</th><td>%1</td>"
@@ -145,15 +145,15 @@ void reportView::render(){
+ "</th><td>%4</td></tr>"
"<tr><th style=\"text-align: right\">" + i18n( "Wind Speed:" )
+ "</th><td>%5</td>")
- .arg(temp).arg(dewPoint).arg(pressure).arg(relHumidity)
- .arg(wind) + "<td width=\"50\">&nbsp;</td>";
+ .tqarg(temp).tqarg(dewPoint).tqarg(pressure).tqarg(relHumidity)
+ .tqarg(wind) + "<td width=\"50\">&nbsp;</td>";
if (!heatIndex.isEmpty())
contents += TQString("<th style=\"text-align: right\">"
- + i18n( "Heat Index:" ) + "</th><td>%1</td>").arg(heatIndex);
+ + i18n( "Heat Index:" ) + "</th><td>%1</td>").tqarg(heatIndex);
else if (!windChill.isEmpty())
contents += TQString("<th style=\"text-align: right\">"
- + i18n( "Wind Chill:" ) + "</th><td>%1</td>").arg(windChill);
+ + i18n( "Wind Chill:" ) + "</th><td>%1</td>").tqarg(windChill);
else
contents += "<td>&nbsp;</td><td>&nbsp;</td>";
contents += "</tr>";
@@ -162,7 +162,7 @@ void reportView::render(){
+ i18n( "Sunrise:" ) + "</th><td>%1</td>" +
"<td width=\"50\">&nbsp;</td><th style=\"text-align: right\">"
+ i18n( "Sunset:" ) + "</th><td>%2</td>")
- .arg(sunRiseTime).arg(sunSetTime);
+ .tqarg(sunRiseTime).tqarg(sunSetTime);
contents += "</tr></table></body></html>";
diff --git a/kweather/serviceconfigdata.ui b/kweather/serviceconfigdata.ui
index 71f6099..befdca2 100644
--- a/kweather/serviceconfigdata.ui
+++ b/kweather/serviceconfigdata.ui
@@ -60,7 +60,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>86</height>
@@ -121,7 +121,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>85</height>
@@ -169,7 +169,7 @@
</widget>
<widget class="TQLayoutWidget" row="5" column="0" rowspan="1" colspan="3">
<property name="name">
- <cstring>layout1</cstring>
+ <cstring>tqlayout1</cstring>
</property>
<hbox>
<property name="name">
diff --git a/kweather/serviceconfigwidget.cpp b/kweather/serviceconfigwidget.cpp
index a71d4b6..08a3b51 100644
--- a/kweather/serviceconfigwidget.cpp
+++ b/kweather/serviceconfigwidget.cpp
@@ -194,7 +194,7 @@ void ServiceConfigWidget::loadLocations()
parseStationEntry( entryIt.data(), station, uid );
new StationItem( stateItem, station, uid );
mStationMap.insert( uid, TQString( "%1, %2" )
- .arg( station ).arg( *stateIt ) );
+ .tqarg( station ).tqarg( *stateIt ) );
}
}
}
diff --git a/kweather/sidebarwidgetbase.ui b/kweather/sidebarwidgetbase.ui
index 6f1f50c..46eb042 100644
--- a/kweather/sidebarwidgetbase.ui
+++ b/kweather/sidebarwidgetbase.ui
@@ -61,7 +61,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>20</height>
diff --git a/kweather/sun.h b/kweather/sun.h
index fd407d7..f56b513 100644
--- a/kweather/sun.h
+++ b/kweather/sun.h
@@ -37,7 +37,7 @@ class Sun
*/
Sun( const TQString &latitude,
const TQString &longitude,
- TQDate date = TQDate::currentDate(),
+ TQDate date = TQDate::tqcurrentDate(),
const int localUTCOffset = KRFCDate::localUTCOffset() );
TQTime computeRiseTime();
diff --git a/kweather/weatherbar.cpp b/kweather/weatherbar.cpp
index a3c5b05..c77333d 100644
--- a/kweather/weatherbar.cpp
+++ b/kweather/weatherbar.cpp
@@ -25,7 +25,7 @@
#include <tqlabel.h>
#include <tqfont.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqscrollview.h>
#include <tqgroupbox.h>
#include <klocale.h>
diff --git a/kweather/weatherbar.h b/kweather/weatherbar.h
index d132d04..0d00c13 100644
--- a/kweather/weatherbar.h
+++ b/kweather/weatherbar.h
@@ -28,7 +28,7 @@
#include <kparts/browserextension.h>
#include <tqdict.h>
#include <dcopobject.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqtimer.h>
class dockwidget;
diff --git a/kweather/weatherbutton.cpp b/kweather/weatherbutton.cpp
index ee88962..ceb4360 100644
--- a/kweather/weatherbutton.cpp
+++ b/kweather/weatherbutton.cpp
@@ -124,14 +124,14 @@ void WeatherButton::slotIconChanged( int group )
return;
generateIcons();
- repaint( false );
+ tqrepaint( false );
}
void WeatherButton::enterEvent( TQEvent *e )
{
m_highlight = true;
- repaint( false );
+ tqrepaint( false );
TQButton::enterEvent( e );
}
@@ -139,7 +139,7 @@ void WeatherButton::leaveEvent( TQEvent *e )
{
m_highlight = false;
- repaint( false );
+ tqrepaint( false );
TQButton::enterEvent( e );
}
diff --git a/kweather/weatherlib.cpp b/kweather/weatherlib.cpp
index 7daf2d7..40eab31 100644
--- a/kweather/weatherlib.cpp
+++ b/kweather/weatherlib.cpp
@@ -18,7 +18,7 @@ email : geiseri@msoe.edu
#include "config.h"
#include <tqfile.h>
#include <tqdatetime.h>
-#include <textstream.h>
+#include <tqtextstream.h>
#include <kglobal.h>
#include <klocale.h>
#include <kdebug.h>
@@ -65,7 +65,7 @@ WeatherLib::Data::Data()
void WeatherLib::Data::clear()
{
- age = TQDateTime::currentDateTime();
+ age = TQDateTime::tqcurrentDateTime();
downloading = false;
updated = false;
job = 0;
@@ -135,7 +135,7 @@ void WeatherLib::slotCopyDone(KIO::Job* job)
kdDebug( 12006 ) << "Parse: " << s << endl;
MetarParser parser(m_StationDb, KGlobal::locale()->measureSystem());
d->wi = parser.processData(d->wi.reportLocation, s);
- d->age = TQDateTime::currentDateTime().addSecs(1800);
+ d->age = TQDateTime::tqcurrentDateTime().addSecs(1800);
emit fileUpdate(d->wi.reportLocation);
d->updated = true;
}
@@ -144,7 +144,7 @@ void WeatherLib::slotCopyDone(KIO::Job* job)
// File error
kdDebug( 12006 ) << "File empty error..." << endl;
KPassivePopup::message( i18n("KWeather Error!"),
- i18n("The temp file %1 was empty.").arg(d->target->name()), 0L,"error" );
+ i18n("The temp file %1 was empty.").tqarg(d->target->name()), 0L,"error" );
d->updated = false;
}
}
@@ -153,7 +153,7 @@ void WeatherLib::slotCopyDone(KIO::Job* job)
// File error
kdDebug( 12006 ) << "File read error..." << endl;
KPassivePopup::message( i18n("KWeather Error!"),
- i18n("Could not read the temp file %1.").arg(d->target->name()), 0L,"error" );
+ i18n("Could not read the temp file %1.").tqarg(d->target->name()), 0L,"error" );
d->updated = false;
}
delete d->target;
@@ -322,7 +322,7 @@ void WeatherLib::update(const TQString &stationID)
// Only grab new data if its more than 50 minutes old
Data *d = findData(stationID);
- TQDateTime timeout = TQDateTime::currentDateTime();
+ TQDateTime timeout = TQDateTime::tqcurrentDateTime();
kdDebug (12006) << "Current Time: " << KGlobal::locale()->formatDateTime(timeout, false, false) <<
" Update at: " << KGlobal::locale()->formatDateTime(d->age, false, false) << endl;
diff --git a/kweather/dockwidget.cpp b/kweather/dockwidget.cpp
index 390d455..04576b1 100644
--- a/kweather/dockwidget.cpp
+++ b/kweather/dockwidget.cpp
@@ -21,7 +21,7 @@
#include "weatherservice_stub.h"
#include <tqtooltip.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlabel.h>
#include <tqtimer.h>
#include <tqobjectlist.h>
@@ -112,19 +112,19 @@ void dockwidget::showWeather()
"<th><nobr>" + i18n( "Rel. Humidity:" ) + "</nobr></th><td><nobr>%4</nobr></td></nobr></tr>"
"<tr><th><nobr>" + i18n( "Wind Speed:" ) + "</nobr></th><td><nobr>%5</nobr></td>")
- .arg(temp).arg(dewPoint).arg(pressure).arg(relHumidity).arg(wind);
+ .tqarg(temp).tqarg(dewPoint).tqarg(pressure).tqarg(relHumidity).tqarg(wind);
if ( !heatIndex.isEmpty() )
- tip += TQString("<th><nobr>" + i18n( "Heat Index:" ) + "</nobr></th><td><nobr>%1</nobr></td>").arg(heatIndex);
+ tip += TQString("<th><nobr>" + i18n( "Heat Index:" ) + "</nobr></th><td><nobr>%1</nobr></td>").tqarg(heatIndex);
else if ( !windChill.isEmpty() )
- tip += TQString("<th><nobr>" + i18n( "Wind Chill:" ) + "</nobr></th><td><nobr>%1</nobr></td>").arg(windChill);
+ tip += TQString("<th><nobr>" + i18n( "Wind Chill:" ) + "</nobr></th><td><nobr>%1</nobr></td>").tqarg(windChill);
else
tip += "<td>&nbsp;</td><td>&nbsp;</td>";
tip += "</tr>";
tip += TQString("<tr><th><nobr>" + i18n( "Sunrise:" ) + "</nobr></th><td><nobr>%1</nobr></td>" +
"<th><nobr>" + i18n( "Sunset:" ) + "</nobr></th><td><nobr>%2</nobr></td>")
- .arg(sunRiseTime).arg(sunSetTime);
+ .tqarg(sunRiseTime).tqarg(sunSetTime);
tip += "</tr></table>";
@@ -184,12 +184,12 @@ void dockwidget::initDock()
mainLayout->setMargin(0);
mainLayout->addWidget(m_button, 0, TQt::AlignCenter);
- TQBoxLayout *layout = new TQBoxLayout(mainLayout, TQBoxLayout::TopToBottom);
- layout->setSpacing(0);
- layout->setMargin(0);
- layout->addWidget(m_lblTemp);
- layout->addWidget(m_lblWind);
- layout->addWidget(m_lblPres);
+ TQBoxLayout *tqlayout = new TQBoxLayout(mainLayout, TQBoxLayout::TopToBottom);
+ tqlayout->setSpacing(0);
+ tqlayout->setMargin(0);
+ tqlayout->addWidget(m_lblTemp);
+ tqlayout->addWidget(m_lblWind);
+ tqlayout->addWidget(m_lblPres);
mainLayout->addSpacing(8);
@@ -210,21 +210,21 @@ void dockwidget::resizeView( const TQSize &size )
if ( m_mode == ShowAll )
{
- if ( h <= 128 ) // left to right layout
+ if ( h <= 128 ) // left to right tqlayout
{
- static_cast<TQBoxLayout*>(layout())->setDirection(TQBoxLayout::LeftToRight);
- m_lblTemp->setAlignment(TQt::AlignAuto | TQt::AlignVCenter);
- m_lblWind->setAlignment(TQt::AlignAuto | TQt::AlignVCenter);
- m_lblPres->setAlignment(TQt::AlignAuto | TQt::AlignVCenter);
+ static_cast<TQBoxLayout*>(tqlayout())->setDirection(TQBoxLayout::LeftToRight);
+ m_lblTemp->tqsetAlignment(TQt::AlignAuto | TQt::AlignVCenter);
+ m_lblWind->tqsetAlignment(TQt::AlignAuto | TQt::AlignVCenter);
+ m_lblPres->tqsetAlignment(TQt::AlignAuto | TQt::AlignVCenter);
}
else // top to bottom
{
- static_cast<TQBoxLayout*>(layout())->setDirection(TQBoxLayout::TopToBottom);
+ static_cast<TQBoxLayout*>(tqlayout())->setDirection(TQBoxLayout::TopToBottom);
TQFontMetrics fm(m_font);
h = 128 - (3 * fm.height()); // 3 lines of text below the button
- m_lblTemp->setAlignment(TQt::AlignCenter);
- m_lblWind->setAlignment(TQt::AlignCenter);
- m_lblPres->setAlignment(TQt::AlignCenter);
+ m_lblTemp->tqsetAlignment(TQt::AlignCenter);
+ m_lblWind->tqsetAlignment(TQt::AlignCenter);
+ m_lblPres->tqsetAlignment(TQt::AlignCenter);
}
m_button->setFixedSize(h, h);
}
@@ -232,15 +232,15 @@ void dockwidget::resizeView( const TQSize &size )
{
if ( h <= 32 ) // left to right
{
- static_cast<TQBoxLayout*>(layout())->setDirection(TQBoxLayout::LeftToRight);
- m_lblTemp->setAlignment(TQt::AlignAuto | TQt::AlignVCenter);
+ static_cast<TQBoxLayout*>(tqlayout())->setDirection(TQBoxLayout::LeftToRight);
+ m_lblTemp->tqsetAlignment(TQt::AlignAuto | TQt::AlignVCenter);
}
else // top to bottom
{
- static_cast<TQBoxLayout*>(layout())->setDirection(TQBoxLayout::TopToBottom);
+ static_cast<TQBoxLayout*>(tqlayout())->setDirection(TQBoxLayout::TopToBottom);
TQFontMetrics fm(m_font);
h = TQMIN(128, h) - fm.height();
- m_lblTemp->setAlignment(TQt::AlignCenter);
+ m_lblTemp->tqsetAlignment(TQt::AlignCenter);
}
m_button->setFixedSize(h, h);
}
@@ -259,21 +259,21 @@ void dockwidget::resizeView( const TQSize &size )
{
if ( w <= 128 ) // top to bottom
{
- static_cast<TQBoxLayout*>(layout())->setDirection(TQBoxLayout::TopToBottom);
- m_lblTemp->setAlignment(TQt::AlignCenter);
- m_lblWind->setAlignment(TQt::AlignCenter);
- m_lblPres->setAlignment(TQt::AlignCenter);
+ static_cast<TQBoxLayout*>(tqlayout())->setDirection(TQBoxLayout::TopToBottom);
+ m_lblTemp->tqsetAlignment(TQt::AlignCenter);
+ m_lblWind->tqsetAlignment(TQt::AlignCenter);
+ m_lblPres->tqsetAlignment(TQt::AlignCenter);
TQFontMetrics fm(m_font);
h = h - (3 * fm.height()); // 3 lines of text below the button
h = TQMIN(w, h);
}
- else // left to right layout
+ else // left to right tqlayout
{
- static_cast<TQBoxLayout*>(layout())->setDirection(TQBoxLayout::LeftToRight);
- m_lblTemp->setAlignment(TQt::AlignAuto | TQt::AlignVCenter);
- m_lblWind->setAlignment(TQt::AlignAuto | TQt::AlignVCenter);
- m_lblPres->setAlignment(TQt::AlignAuto | TQt::AlignVCenter);
+ static_cast<TQBoxLayout*>(tqlayout())->setDirection(TQBoxLayout::LeftToRight);
+ m_lblTemp->tqsetAlignment(TQt::AlignAuto | TQt::AlignVCenter);
+ m_lblWind->tqsetAlignment(TQt::AlignAuto | TQt::AlignVCenter);
+ m_lblPres->tqsetAlignment(TQt::AlignAuto | TQt::AlignVCenter);
}
m_button->setFixedSize(h, h);
}
@@ -281,15 +281,15 @@ void dockwidget::resizeView( const TQSize &size )
{
if ( w <= 128 ) // top to bottom
{
- static_cast<TQBoxLayout*>(layout())->setDirection(TQBoxLayout::TopToBottom);
- m_lblTemp->setAlignment(TQt::AlignCenter);
+ static_cast<TQBoxLayout*>(tqlayout())->setDirection(TQBoxLayout::TopToBottom);
+ m_lblTemp->tqsetAlignment(TQt::AlignCenter);
h = w;
}
- else // left to right layout
+ else // left to right tqlayout
{
- static_cast<TQBoxLayout*>(layout())->setDirection(TQBoxLayout::LeftToRight);
- m_lblTemp->setAlignment(TQt::AlignAuto | TQt::AlignVCenter);
+ static_cast<TQBoxLayout*>(tqlayout())->setDirection(TQBoxLayout::LeftToRight);
+ m_lblTemp->tqsetAlignment(TQt::AlignAuto | TQt::AlignVCenter);
h = static_cast<int>(w * 0.33);
}
@@ -310,7 +310,7 @@ int dockwidget::widthForHeight(int h)
if ( m_mode == ShowAll )
{
- if ( h <= 128 ) // left to right layout
+ if ( h <= 128 ) // left to right tqlayout
{
int pixelSize = h/3 - 3;
pixelSize = TQMIN(pixelSize, fi.pixelSize()); // don't make it too large
@@ -337,7 +337,7 @@ int dockwidget::widthForHeight(int h)
}
else if ( m_mode == ShowTempOnly )
{
- if ( h <= 32 ) // left to right layout
+ if ( h <= 32 ) // left to right tqlayout
{
int pixelSize = h - 3;
pixelSize = TQMIN(pixelSize, fi.pixelSize()); // don't make it too large